Release history
===============


Version 0.5.2 (2017-11-10)
--------------------------

A source distribution packaging bug was fixed.


Version 0.5.1 (2017-08-15)
--------------------------

This release fixes a few places in docs.


Version 0.5 (2017-08-15)
------------------------

Ported to Python 3, still compatible with Python 2.7.  Python 3 support requires protobuf 3.0.0 or newer.

This version still only supports 'proto2' syntax.


Version 0.1 (2013-10-08)
------------------------

Initial release.
